Package: gclus
Version: 1.3.3
Authors@R: person(given = "Catherine", family = "Hurley", 
           email = "catherine.hurley@mu.ie", role = c("aut", "cre"))
Date: 2025-03-28
Maintainer: Catherine Hurley <catherine.hurley@mu.ie>
Title: Clustering Graphics
Description: Orders panels in scatterplot matrices and parallel coordinate
 displays by some merit index. Package contains various indices of merit,
 ordering functions, and enhanced versions of pairs and parcoord which
 color panels according to their merit level.
Depends: R (>= 2.10), cluster
License: GPL (>= 2)
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-03-28 11:19:57 UTC; catherine
Author: Catherine Hurley [aut, cre]
Repository: CRAN
Date/Publication: 2025-03-28 12:30:02 UTC
Built: R 4.3.3; ; 2025-03-28 14:20:07 UTC; unix
