# Default NAMESPACE created by R
# Remove the previous line if you edit this file

# Export all names
exportPattern(".")

# Import all packages listed as Imports or Depends
import(
  cluster,compiler
)

S3method(reorder,hclust)
import(graphics)
import(stats)
import(compiler)